@@ -15,8 +15,9 @@
 #include "xb-builder-source-ctx-private.h"
 #include "xb-builder-source-private.h"
 #include "xb-lzma-decompressor.h"
+#ifdef HAVE_ZSTD
 #include "xb-zstd-decompressor.h"
-
+#endif
 typedef struct {
 	GInputStream *istream;
 	GFile *file;
@@ -307,6 +308,10 @@ xb_builder_source_init_adapter(XbBuilderSource *self,
  * Adds a function that can be used to convert streams loaded with
  * xb_builder_source_load_xml().
  *
+ * This will decompress multiple layers of content, for instance decompressing a gzip stream into a
+ * different content type that can then be parsed. Use xb_builder_source_add_simple_adapter() when
+ * this recursive behaviour is not desired.
+ *
  * Since: 0.1.7
  **/
 void
@@ -330,6 +335,10 @@ xb_builder_source_add_adapter(XbBuilderSource *self,
  * Adds a function that can be used to convert streams loaded with
  * xb_builder_source_load_xml().
  *
+ * This function is similar to xb_builder_source_add_adapter() but is limited to one "layer" of
+ * content, for instance handling application/xml or a single simple type added using
+ * xb_builder_source_add_adapter().
+ *
  * Since: 0.1.15
  **/
 void
@@ -527,7 +536,7 @@ xb_builder_source_load_lzma_cb(XbBuilderSource *self,
 	g_autoptr(GConverter) conv = G_CONVERTER(xb_lzma_decompressor_new());
 	return g_converter_input_stream_new(istream, conv);
 }
-
+#ifdef HAVE_ZSTD
 static GInputStream *
 xb_builder_source_load_zstd_cb(XbBuilderSource *self,
 			       XbBuilderSourceCtx *ctx,
@@ -539,7 +548,7 @@ xb_builder_source_load_zstd_cb(XbBuilderSource *self,
 	g_autoptr(GConverter) conv = G_CONVERTER(xb_zstd_decompressor_new());
 	return g_converter_input_stream_new(istream, conv);
 }
-
+#endif
 static void
 xb_builder_source_adapter_free(XbBuilderSourceAdapter *item)
 {
@@ -585,20 +594,22 @@ xb_builder_source_init(XbBuilderSource *self)
 	priv->adapters =
 	    g_ptr_array_new_with_free_func((GDestroyNotify)xb_builder_source_adapter_free);
 	xb_builder_source_add_adapter(self,
-				      "application/gzip,application/x-gzip",
+				      "application/gzip,application/x-gzip,org.gnu.gnu-zip-archive",
 				      xb_builder_source_load_gzip_cb,
 				      NULL,
 				      NULL);
 	xb_builder_source_add_adapter(self,
-				      "application/x-xz",
+				      "application/x-xz,org.tukaani.xz-archive",
 				      xb_builder_source_load_lzma_cb,
 				      NULL,
 				      NULL);
+#ifdef HAVE_ZSTD
 	xb_builder_source_add_adapter(self,
 				      "application/zstd",
 				      xb_builder_source_load_zstd_cb,
 				      NULL,
 				      NULL);
+#endif
 }
 
 /**
