@@ -32,6 +32,8 @@ xb_opcode_kind_to_string(XbOpcodeKind kind)
 		return "BIND";
 	if (kind == XB_OPCODE_KIND_BOUND_TEXT)
 		return "?TXT";
+	if (kind == XB_OPCODE_KIND_BOUND_INDEXED_TEXT)
+		return "?ITX";
 	if (kind == XB_OPCODE_KIND_BOUND_INTEGER)
 		return "?INT";
 	if (kind == XB_OPCODE_KIND_INDEXED_TEXT)
@@ -70,6 +72,8 @@ xb_opcode_kind_from_string(const gchar *str)
 		return XB_OPCODE_KIND_BOUND_INTEGER;
 	if (g_strcmp0(str, "?TXT") == 0)
 		return XB_OPCODE_KIND_BOUND_TEXT;
+	if (g_strcmp0(str, "?ITX") == 0)
+		return XB_OPCODE_KIND_BOUND_INDEXED_TEXT;
 	if (g_strcmp0(str, "?INT") == 0)
 		return XB_OPCODE_KIND_BOUND_INTEGER;
 	if (g_strcmp0(str, "TEXI") == 0)
@@ -104,12 +108,6 @@ xb_opcode_set_level(XbOpcode *self, guint8 level)
 	self->level = level;
 }
 
-guint8
-xb_opcode_get_level(XbOpcode *self)
-{
-	return self->level;
-}
-
 static gchar *
 xb_opcode_to_string_internal(XbOpcode *self)
 {
@@ -120,7 +118,8 @@ xb_opcode_to_string_internal(XbOpcode *self)
 		g_string_append_printf(str, "$'%s'", xb_opcode_get_str_for_display(self));
 	else if (self->kind == XB_OPCODE_KIND_INTEGER)
 		g_string_append_printf(str, "%u", xb_opcode_get_val(self));
-	else if (self->kind == XB_OPCODE_KIND_BOUND_TEXT)
+	else if (self->kind == XB_OPCODE_KIND_BOUND_TEXT ||
+		 self->kind == XB_OPCODE_KIND_BOUND_INDEXED_TEXT)
 		g_string_append_printf(str, "?'%s'", xb_opcode_get_str_for_display(self));
 	else if (self->kind == XB_OPCODE_KIND_BOUND_INTEGER)
 		g_string_append_printf(str, "?%u", xb_opcode_get_val(self));
@@ -224,8 +223,7 @@ xb_opcode_add_flag(XbOpcode *self, XbOpcodeFlags flag)
 inline gboolean
 xb_opcode_cmp_val(XbOpcode *self)
 {
-	return self->kind == XB_OPCODE_KIND_INTEGER || self->kind == XB_OPCODE_KIND_BOOLEAN ||
-	       self->kind == XB_OPCODE_KIND_BOUND_INTEGER;
+	return _xb_opcode_cmp_int(self) || _xb_opcode_cmp_itx(self);
 }
 
 /**
@@ -281,7 +279,7 @@ xb_opcode_get_val(XbOpcode *self)
 const gchar *
 xb_opcode_get_str(XbOpcode *self)
 {
-	return self->ptr;
+  return _xb_opcode_get_str(self);
 }
 
 /**
@@ -359,6 +357,7 @@ xb_opcode_init(XbOpcode *self,
 	self->val = val;
 	self->tokens_len = 0;
 	self->destroy_func = destroy_func;
+	memset(self->tokens, 0, sizeof(self->tokens));
 }
 
 /**
