@@ -11,6 +11,7 @@
 
 #include "xb-builder-node.h"
 #include "xb-builder.h"
+#include "xb-common-private.h"
 #include "xb-machine.h"
 #include "xb-node-query.h"
 #include "xb-opcode-private.h"
@@ -163,6 +164,34 @@ xb_common_func(void)
 	g_assert_false(xb_string_token_valid("ab"));
 }
 
+static void
+xb_common_content_type_func(void)
+{
+	struct {
+		const gchar *fn;
+		const gchar *ctype;
+	} items[] = {{"test.desktop", "application/x-desktop"},
+		     {"test.quirk", "text/plain"},
+		     {"test.xml", "application/xml"},
+		     {"test.xml.gz.gz.gz", "application/gzip"},
+		     {"test.xml.xz", "application/x-xz"},
+		     {"test.xml.zstd", "application/zstd"},
+		     {NULL, NULL}};
+	for (guint i = 0; items[i].fn != NULL; i++) {
+		gboolean ret;
+		gsize bufsz = 0;
+		g_autofree gchar *buf = NULL;
+		g_autofree gchar *ctype = NULL;
+		g_autofree gchar *fn = g_test_build_filename(G_TEST_DIST, items[i].fn, NULL);
+		g_autoptr(GError) error = NULL;
+		ret = g_file_get_contents(fn, &buf, &bufsz, &error);
+		g_assert_no_error(error);
+		g_assert_true(ret);
+		ctype = xb_content_type_guess(fn, (const guchar *)buf, bufsz);
+		g_assert_cmpstr(ctype, ==, items[i].ctype);
+	}
+}
+
 static void
 xb_common_searchv_func(void)
 {
@@ -1256,7 +1285,7 @@ xb_xpath_query_func(void)
 	g_autoptr(XbNode) n = NULL;
 	g_autoptr(XbSilo) silo = NULL;
 	const gchar *xml = "<components>\n"
-			   "  <component>\n"
+			   "  <component timestamp=\"1631923200\">\n"
 			   "    <id>n/a</id>\n"
 			   "  </component>\n"
 			   "</components>\n";
@@ -1287,6 +1316,13 @@ xb_xpath_query_func(void)
 	g_assert_cmpstr(xb_node_get_text(n), ==, "n/a");
 	g_clear_object(&n);
 
+	/* query using an integer */
+	n = xb_silo_query_first(silo, "components/component[@timestamp=1631923200]", &error);
+	g_assert_no_error(error);
+	g_assert_nonnull(n);
+	g_assert_cmpstr(xb_node_get_attr(n, "timestamp"), ==, "1631923200");
+	g_clear_object(&n);
+
 	/* query with an OR, all sections contains an unknown element */
 	n = xb_silo_query_first(silo, "components/dave|components/mike", &error);
 	g_assert_error(error, G_IO_ERROR, G_IO_ERROR_NOT_FOUND);
@@ -1690,6 +1726,79 @@ xb_xpath_func(void)
 	g_assert_cmpstr(xml_sub3, ==, "<id>org.hughski.ColorHug2.firmware</id>");
 }
 
+static void
+xb_manual_token_search_func(void)
+{
+	XbNode *n;
+	g_autoptr(XbNode) cpt_node = NULL;
+	g_autoptr(XbBuilder) builder = NULL;
+	g_autoptr(XbBuilderNode) bn_root = NULL;
+	g_autoptr(XbBuilderNode) bn = NULL;
+	g_autoptr(XbSilo) silo = NULL;
+	g_autofree gchar *str = NULL;
+	g_autoptr(XbQuery) query = NULL;
+	g_autoptr(GPtrArray) result = NULL;
+	g_autoptr(GError) error = NULL;
+	g_auto(XbQueryContext) context = XB_QUERY_CONTEXT_INIT();
+
+	/* create node tree and add a dummy token manually */
+	bn_root = xb_builder_node_new("component");
+	bn = xb_builder_node_new("summary");
+	xb_builder_node_set_text(bn, "A strategy game", -1);
+	xb_builder_node_add_token(bn, "strategy"); /* or use XB_BUILDER_NODE_FLAG_TOKENIZE_TEXT */
+	xb_builder_node_add_token(bn, "strategi");
+	xb_builder_node_add_child(bn_root, bn);
+
+	builder = xb_builder_new();
+	xb_builder_import_node(builder, bn_root);
+
+	silo = xb_builder_compile(builder, XB_BUILDER_COMPILE_FLAG_NONE, NULL, &error);
+	g_assert_no_error(error);
+	g_assert_nonnull(silo);
+
+	/* dump to screen */
+	str = xb_silo_to_string(silo, &error);
+	g_assert_no_error(error);
+	g_assert_nonnull(str);
+	g_debug("\n%s", str);
+
+	/* get component node */
+	cpt_node = xb_silo_query_first(silo, "component", &error);
+	g_assert_no_error(error);
+	g_assert_nonnull(cpt_node);
+
+	/* search using the slow, token-less path */
+	query = xb_query_new(silo, "summary[text()~=?]", &error);
+	g_assert_no_error(error);
+	g_assert_nonnull(query);
+
+	xb_value_bindings_bind_str(xb_query_context_get_bindings(&context), 0, "strategy", NULL);
+	result = xb_node_query_with_context(cpt_node, query, &context, &error);
+	g_assert_no_error(error);
+	g_assert_nonnull(result);
+
+	n = XB_NODE(g_ptr_array_index(result, 0));
+	g_assert_nonnull(n);
+	g_assert_cmpstr(xb_node_get_text(n), ==, "A strategy game");
+	g_clear_object(&query);
+	g_ptr_array_unref(g_steal_pointer(&result));
+
+	/* search for token */
+	xb_silo_set_profile_flags(silo, ~0);
+	query = xb_query_new(silo, "summary[text()~=?]", &error);
+	g_assert_no_error(error);
+	g_assert_nonnull(query);
+
+	xb_value_bindings_bind_str(xb_query_context_get_bindings(&context), 0, "strategi", NULL);
+	result = xb_node_query_with_context(cpt_node, query, &context, &error);
+	g_assert_no_error(error);
+	g_assert_nonnull(result);
+
+	n = XB_NODE(g_ptr_array_index(result, 0));
+	g_assert_nonnull(n);
+	g_assert_cmpstr(xb_node_get_text(n), ==, "A strategy game");
+}
+
 static void
 xb_builder_native_lang_func(void)
 {
@@ -2761,6 +2870,8 @@ xb_speed_func(void)
 int
 main(int argc, char **argv)
 {
+	g_setenv("G_TEST_SRCDIR", SRCDIR, FALSE);
+
 	g_test_init(&argc, &argv, NULL);
 
 	/* only critical and error are fatal */
@@ -2771,6 +2882,7 @@ main(int argc, char **argv)
 
 	/* tests go here */
 	g_test_add_func("/libxmlb/common", xb_common_func);
+	g_test_add_func("/libxmlb/common{content-type}", xb_common_content_type_func);
 	g_test_add_func("/libxmlb/common{searchv}", xb_common_searchv_func);
 	g_test_add_func("/libxmlb/common{union}", xb_common_union_func);
 	g_test_add_func("/libxmlb/opcodes", xb_predicate_func);
@@ -2806,6 +2918,7 @@ main(int argc, char **argv)
 	g_test_add_func("/libxmlb/builder-node{literal-text}", xb_builder_node_literal_text_func);
 	g_test_add_func("/libxmlb/builder-node{source-text}", xb_builder_node_source_text_func);
 	g_test_add_func("/libxmlb/markup", xb_markup_func);
+	g_test_add_func("/libxmlb/token-search", xb_manual_token_search_func);
 	g_test_add_func("/libxmlb/xpath", xb_xpath_func);
 	g_test_add_func("/libxmlb/xpath-query", xb_xpath_query_func);
 	g_test_add_func("/libxmlb/xpath-query{reverse}", xb_xpath_query_reverse_func);
